@@ -6,10 +6,28 @@ import os.path
 import nox
 
 
-nox.options.sessions = ['mypy', 'test']
+nox.options.sessions = ['docs', 'mypy', 'test']
 nox.options.reuse_existing_virtualenvs = True
 
 
+@nox.session()
+def docs(session):
+    """
+    Build the docs. Pass "serve" to serve.
+    """
+
+    session.install('.[docs]')
+    session.chdir('docs')
+    session.run('sphinx-build', '-M', 'html', '.', '_build')
+
+    if session.posargs:
+        if 'serve' in session.posargs:
+            print('Launching docs at http://localhost:8000/ - use Ctrl-C to quit')
+            session.run('python', '-m', 'http.server', '8000', '-d', '_build/html')
+        else:
+            print('Unsupported argument to docs')
+
+
 @nox.session(python='3.7')
 def mypy(session):
     session.install('mypy')
@@ -17,7 +35,7 @@ def mypy(session):
     session.run('mypy', '-p', 'mesonpy')
 
 
-@nox.session(python=['3.7', '3.8', '3.9', '3.10'])
+@nox.session(python=['3.7', '3.8', '3.9', '3.10', '3.11'])
 def test(session):
     htmlcov_output = os.path.join(session.virtualenv.location, 'htmlcov')
     xmlcov_output = os.path.join(session.virtualenv.location, f'coverage-{session.python}.xml')
